Learn R Programming

hkevp (version 1.1.6)

hkevp.expmeasure: Exponent measure of the HKEVP

Description

Exponent measure \(V(z_1,...,z_n)\) of the HKEVP of Reich and Shaby (2012), with given model parameters or output from hkevp.fit or latent.fit.

Usage

hkevp.expmeasure(z, sites, knots, alpha, tau, fit)

Value

Either a vector if argument fit is provided, or a single value.

Arguments

z

The vector \((z_1,...,z_n)\) where the exponent measure is computed. Can be of length one and thus corresponds then to \((z,...,z)\).

sites

The coordinates of the sites where the data are observed. Each row correspond to a site position.

knots

The coordinates of the knots in the HKEVP. By default, the positions of the knots coincide with the positions of the sites.

alpha

The dependence parameter \(\alpha\) of the HKEVP: a single value in (0,1].

tau

The bandwidth parameter \(\tau\) of the kernel functions in the HKEVP: a positive value.

fit

Output from the hkevp.fit procedure.

Author

Quentin Sebille

Details

The exponent measure describes the spatial dependence structure of a max-stable process, independently from the values of the marginal parameters. If \(Z(\cdot)\) is a simple max-stable process, i.e. with unit GEV(1,1,1) margins, recorded at the set of sites \((s_1, \ldots, s_n)\), its joint cumulative probability density function is given by: $$P\{ Z(s_1)\leq z_1, \ldots, Z(s_n)\leq z_n \} = \exp(-V(z_1, \ldots, z_n)) ~,$$ where \(V\) is the so-called exponent measure. For the HKEVP, the exponent measure is explicit for any number \(n\) of sites: $$V(z_1, \ldots, z_n) = \sum_{\ell=1}^L \left[ \sum_{i=1}^n \left(\frac{\omega_\ell(s_i)}{z_i}\right)^{1/\alpha}\right]^{\alpha} ~.$$

If argument fit is provided, the predictive distribution of $$V(z_1, \ldots, z_n)$$ is computed. If not, the function uses arguments sites, knots, alpha, and tau.

References

Reich, B. J., & Shaby, B. A. (2012). A hierarchical max-stable spatial model for extreme precipitation. The annals of applied statistics, 6(4), 1430. <DOI:10.1214/12-AOAS591>

Examples

Run this code
# \donttest{
sites <- as.matrix(expand.grid(1:3,1:3))
loc <- sites[,1]*10
scale <- 3
shape <- 0
alpha <- .4
tau <- 1
ysim <- hkevp.rand(10, sites, sites, loc, scale, shape, alpha, tau)

# HKEVP fit:
fit <- hkevp.fit(ysim, sites, niter = 1000)

predict.em <- hkevp.expmeasure(1, fit = fit)
true.em <- hkevp.expmeasure(1, sites, sites, alpha, tau)
# plot(predict.em, ylim = range(predict.em, true.em), type = "l")
# abline(h = true.em, col = 2, lwd = 2)
# }

Run the code above in your browser using DataLab