A numerical matrix of real values.
Each column corresponds to a position and each row to a realisation of the process.
Arguments
nrep
A positive integer.
Number of realisations of the block mashapema process.
sites
The coordinates of the sites where the data are observed. Each row corresponds to a site position.
knots
The coordinates of the knots in the HKEVP. By default, the positions of the knots coincide with the positions of the sites.
loc
A numerical value or a vector of real values for the GEV location parameter. If a vector, its length must coincide with the number of sites. The value by default is 1.
scale
A numerical value or a vector of real values for the GEV scale parameter. If a vector, its length must coincide with the number of sites. The value by default is 1.
shape
A numerical value or a vector of real values for the GEV shape parameter. If a vector, its length must coincide with the number of sites. The value by default is 1.
alpha
The dependence parameter \(\alpha\) of the HKEVP: a single value in (0,1].
tau
The bandwidth parameter \(\tau\) of the kernel functions in the HKEVP: a positive value.
Author
Quentin Sebille
Details
Simulating one realisation of the block mashapema process \(Y(\cdot)\) from the HKEVP involves three steps:
The nugget process \(U(\cdot)\) is generated independently at each position, by simulating a random variable with \(GEV(1,\alpha,\alpha)\) distribution.
The residual dependence process \(\theta(\cdot)\) is computed by using the kernel functions centered at the set of knots, the bandwidth parameter \(\tau\) and the simulations of the positive stable \(PS(\alpha)\) random effect \(A\).
The process \(Z = U\theta\) is computed and its margins are transformed to the general GEV distribution with \(\mu(s),\sigma(s)\) and \(\xi(s)\) parameters.