Learn R Programming

hkevp (version 1.1.6)

mcmc.fun: Point estimates of HKEVP fit

Description

Application of a function to the main Markov chains resulting from the procedure hkevp.fit. May be used to obtain point estimates of the posterior distribution (e.g., the mean or the median). See details.

Usage

mcmc.fun(fit, FUN, ...)

Value

If fitted model is the HKEVP, a named list with three elements:

  • GEV: A numerical matrix. Result of the function FUN for each GEV parameter (columns) and each site position (rows).

  • alpha: A numerical value. Result of the function FUN on the Markov chain associated to the dependence parameter \(\alpha\).

  • tau: A numerical value. Result of the function FUN on the Markov chain associated to the bandwidth parameter \(\tau\).

If fitted model is the latent variable model, the functions returns the GEV matrix only.

Arguments

fit

A named list. Output from the hkevp.fit procedure.

FUN

The function applied to the Markov chains in fit. The median by default. The output from FUN must be a single value.

...

Optional arguments of the function to be applied on the Markov chains (e.g. na.rm = FALSE).

Author

Quentin Sebille

Details

A function is applied to the main Markov chains resulting from the MCMC procedures hkevp.fit or latent.fit. These chains correspond to the three GEV parameters, the dependence parameter \(\alpha\) and the bandwidth \(\tau\).

The value returned by FUN must be a single value.

Examples

Run this code
# Simulation of HKEVP:
# \donttest{
sites <- as.matrix(expand.grid(1:3,1:3))
knots <- sites
loc <- sites[,1]*10
scale <- 3
shape <- .2
alpha <- .4
tau <- 1
ysim <- hkevp.rand(10, sites, knots, loc, scale, shape, alpha, tau)

# HKEVP fit:
fit <- hkevp.fit(ysim, sites, niter = 1000)

# Posterior median and standard deviation:
# mcmc.fun(fit, median)
# mcmc.fun(fit, sd)
# }


Run the code above in your browser using DataLab